@@ -1,15 +1,15 @@
 /* This generated file is for internal use. Do not include it from headers. */
 
-#ifdef CONFIG_H
+#ifdef CLANG_CONFIG_H
 #error config.h can only be included once
 #else
-#define CONFIG_H
+#define CLANG_CONFIG_H
 
 /* Bug report URL. */
 #define BUG_REPORT_URL "http://llvm.org/bugs/"
 
 /* Default OpenMP runtime used by -fopenmp. */
-#define CLANG_DEFAULT_OPENMP_RUNTIME "libgomp"
+#define CLANG_DEFAULT_OPENMP_RUNTIME "libomp"
 
 /* Multilib suffix for libdir. */
 #define CLANG_LIBDIR_SUFFIX ""
@@ -30,7 +30,7 @@
 #define CLANG_HAVE_LIBXML 1
 
 /* The LLVM product name and version */
-#define BACKEND_PACKAGE_STRING "LLVM 3.7.0"
+#define BACKEND_PACKAGE_STRING "LLVM 3.8.1"
 
 /* Linker version detected at compile time. */
 /* #undef HOST_LINK_VERSION */
